@@ -11,9 +11,10 @@ BUILD_IMAGE="${BUILD_IMAGE:-false}"
 BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
 ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
 ZUUL_BRANCH=${ZUUL_BRANCH:-}
-ENABLE_VENV=true
 CLI_TEST=${CLI_TEST:-false}
 BOOT_MODE=${BOOT_MODE:-}
+ENABLE_TLS=${ENABLE_TLS:-false}
+ENABLE_PROMETHEUS_EXPORTER=${ENABLE_PROMETHEUS_EXPORTER:-false}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -22,7 +23,7 @@ BOOT_MODE=${BOOT_MODE:-}
 # for the default and DHCP tests are to drive the use of Cirros as the
 # deployed operating system, and as such sets the test user to cirros,
 # and writes a debian style interfaces file out to the configuration
-# drive as cirros does not support the network_info.json format file
+# drive as cirros does not support the network_data.json format file
 # placed in the configuration drive. The "build image" test does not
 # use cirros.
 
@@ -162,14 +163,13 @@ export BIFROST_INVENTORY_SOURCE=${BAREMETAL_DATA_FILE}
 
 ${ANSIBLE} -vvvv \
     -i inventory/bifrost_inventory.py \
+    -i inventory/target \
     ${TEST_PLAYBOOK} \
-    -e ansible_python_interpreter="${ANSIBLE_PYTHON_INTERP}" \
     -e use_cirros=${USE_CIRROS} \
     -e testing_user=${TESTING_USER} \
     -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
     -e inventory_dhcp=${INVENTORY_DHCP} \
     -e inventory_dhcp_static_ip=${INVENTORY_DHCP_STATIC_IP} \
-    -e enable_venv=${ENABLE_VENV} \
     -e enable_inspector=${USE_INSPECTOR} \
     -e inspect_nodes=${INSPECT_NODES} \
     -e download_ipa=${DOWNLOAD_IPA} \
@@ -178,9 +178,11 @@ ${ANSIBLE} -vvvv \
     -e wait_timeout=${PROVISION_WAIT_TIMEOUT} \
     -e noauth_mode=${NOAUTH_MODE} \
     -e enable_keystone=${ENABLE_KEYSTONE} \
-    -e use_public_urls=${ENABLE_KEYSTONE} \
     -e wait_for_node_deploy=${WAIT_FOR_DEPLOY} \
     -e not_enrolled_data_file=${BAREMETAL_DATA_FILE}.rest \
+    -e enable_tls=${ENABLE_TLS} \
+    -e enable_prometheus_exporter=${ENABLE_PROMETHEUS_EXPORTER} \
+    -e generate_tls=${ENABLE_TLS} \
     -e skip_install=${CLI_TEST} \
     -e skip_package_install=${CLI_TEST} \
     -e skip_bootstrap=${CLI_TEST} \
